Package: rockchalk
Type: Package
Title: Regression Estimation and Presentation
Version: 1.8.164
Date: 2026-04-15
Authors@R: c(person("Paul E.","Johnson",email="pauljohn32@freefaculty.org",role = c("aut", "cre")),
    person("Gabor", "Grothendieck",email="ggrothendieck@gmail.com", role="ctb"),
    person("Dimitri", "Papadopoulos OrfanosGabor", email="dimitri.papadopoulos@cea.fr", role="ctb"))
Maintainer: Paul E. Johnson <pauljohn32@freefaculty.org>
Description: A collection of functions for interpretation and presentation
    of regression analysis.  These functions are used
    to produce the statistics lectures in
    <https://pj.freefaculty.org/guides/>. Includes regression
    diagnostics, regression tables, and plots of interactions and
    "moderator" variables. The emphasis is on "mean-centered" and
    "residual-centered" predictors. The vignette 'rockchalk' offers a
    fairly comprehensive overview.  The vignette 'Rstyle' has advice
    about coding in R.  The package title 'rockchalk' refers to our
    school motto, 'Rock Chalk Jayhawk, Go K.U.'.
License: GPL (>= 3.0)
LazyLoad: yes
Depends: R (>= 2.10)
Imports: grDevices, methods, lme4, carData, MASS, kutils, reformulas
        (>= 0.4.3)
Suggests: tables, Hmisc, car, mvtnorm, scatterplot3d, HH
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-15 15:36:21 UTC; pauljohn
Author: Paul E. Johnson [aut, cre],
  Gabor Grothendieck [ctb],
  Dimitri Papadopoulos OrfanosGabor [ctb]
Repository: CRAN
Date/Publication: 2026-04-16 07:10:08 UTC
Built: R 4.6.0; ; 2026-04-26 06:11:33 UTC; unix
