# Generated by roxygen2: do not edit by hand

S3method(getFocal,character)
S3method(getFocal,default)
S3method(getFocal,factor)
S3method(meanCenter,default)
S3method(model.data,default)
S3method(newdata,default)
S3method(pctable,character)
S3method(pctable,default)
S3method(pctable,formula)
S3method(plot,testSlopes)
S3method(plotPlane,default)
S3method(plotSlopes,lm)
S3method(predict,mcreg)
S3method(predict,rcreg)
S3method(print,mcreg)
S3method(print,pctable)
S3method(print,stdreg)
S3method(print,summarize)
S3method(print,summary.mcreg)
S3method(print,summary.pctable)
S3method(print,summary.stdreg)
S3method(residualCenter,default)
S3method(standardize,lm)
S3method(summary,mcreg)
S3method(summary,pctable)
S3method(summary,stdreg)
export(addLines)
export(centerNumerics)
export(centralValues)
export(combineLevels)
export(cutByQuantile)
export(cutBySD)
export(cutByTable)
export(cutFancy)
export(descriptiveTable)
export(dir.create.unique)
export(drawnorm)
export(focalVals)
export(formatSummarizedFactors)
export(formatSummarizedNumerics)
export(genCorrelatedData)
export(genCorrelatedData2)
export(genCorrelatedData3)
export(genX)
export(getDeltaRsquare)
export(getFocal)
export(getPartialCor)
export(gmc)
export(kurtosis)
export(lazyCor)
export(lazyCov)
export(lmAuxiliary)
export(magRange)
export(makeSymmetric)
export(mcDiagnose)
export(mcGraph1)
export(mcGraph2)
export(mcGraph3)
export(meanCenter)
export(model.data)
export(mvrnorm)
export(newdata)
export(outreg)
export(outreg2HTML)
export(padW0)
export(pctable)
export(perspEmpty)
export(plotCurves)
export(plotPlane)
export(plotSeq)
export(plotSlopes)
export(predictOMatic)
export(rbindFill)
export(removeNULL)
export(residualCenter)
export(skewness)
export(standardize)
export(summarize)
export(summarizeFactors)
export(summarizeNumerics)
export(testSlopes)
export(vech2Corr)
export(vech2mat)
export(waldt)
import(MASS)
import(carData)
import(grDevices)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,axis)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,plot.default)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,text)
importFrom(kutils,mgsub)
importFrom(lme4,VarCorr)
importFrom(methods,as)
importFrom(methods,formalArgs)
importFrom(reformulas,formatVC)
importFrom(stats,AIC)
importFrom(stats,addmargins)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,df.residual)
importFrom(stats,dnorm)
importFrom(stats,drop1)
importFrom(stats,embed)
importFrom(stats,family)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,napredict)
importFrom(stats,nobs)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,predict.lm)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,resid)
importFrom(stats,rlogis)
importFrom(stats,rnorm)
importFrom(stats,rt)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(utils,browseURL)
importFrom(utils,methods)
importFrom(utils,modifyList)
